/**
 * Copyright (C) 2011 Agrosense <info@cloudfarming.nl>
 *
 * Licensed under the Eclipse Public License - v 1.0 (the "License"); you may
 * not use this file except in compliance with the License. You may obtain a
 * copy of the License at
 *
 * http://www.eclipse.org/legal/epl-v10.html
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS, WITHOUT
 * WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied. See the
 * License for the specific language governing permissions and limitations under
 * the License.
 */
package nl.cloudfarming.client.field;

import java.awt.event.ActionEvent;
import java.awt.event.ActionListener;
import java.io.File;
import java.io.IOException;
import javax.swing.AbstractAction;
import nl.cloudfarming.client.field.model.FieldImportSource;
import org.openide.awt.ActionID;
import org.openide.awt.ActionReference;
import org.openide.awt.ActionReferences;
import org.openide.awt.ActionRegistration;
import org.openide.filesystems.FileChooserBuilder;
import org.openide.filesystems.FileObject;
import org.openide.filesystems.FileUtil;
import org.openide.loaders.DataLoader;
import org.openide.loaders.DataObject;
import org.openide.loaders.DataObjectNotFoundException;
import org.openide.util.Exceptions;
import org.openide.util.NbBundle;

/**
 *
 * @author Timon Veenstra
 */
@ActionID(category = "Project",
id = "nl.cloudfarming.client.field.ImportAction")
@ActionRegistration(iconBase = "nl/cloudfarming/client/field/map_add.png",
displayName = "#CTL_ImportFieldFiles")
@ActionReferences({
    @ActionReference(path = "Menu/File", position = 0)
})
@NbBundle.Messages({"CTL_ImportFieldFiles=Import Fields"})
public class ImportAction extends AbstractAction implements ActionListener {

    private final FieldProject project;

    public ImportAction(FieldProject project) {
        this.project = project;
    }

    @Override
    public void actionPerformed(ActionEvent e) {
        FileChooserBuilder builder = new FileChooserBuilder(ImportAction.class).setTitle("Import field files").setApproveText("Import");

        File chosenFile = builder.showOpenDialog();

        if (chosenFile != null) {
            FileObject selectedFileObject = FileUtil.toFileObject(chosenFile);
            try {
                DataObject dataObject = DataObject.find(selectedFileObject);
                for (FileObject fileObject : dataObject.getLookup().lookup(FieldImportSource.class).getFiles()) {
                    fileObject.copy(project.getImportFolder(true), fileObject.getName(), fileObject.getExt());
                }
            } catch (DataObjectNotFoundException ex) {
                Exceptions.printStackTrace(ex);
            } catch (IOException ex) {
                Exceptions.printStackTrace(ex);
            }
        }
    }
}